function plugindef()
   -- This function and the 'finaleplugin' namespace
   -- are both reserved for the plug-in definition.
   finaleplugin.MinJWLuaVersion = "0.54"
   finaleplugin.Author = "Harald Schollmeyer"
   finaleplugin.Version = "1.0"
   finaleplugin.Date = "1.10.2019"
   finaleplugin.AuthorEmail = "hschollm@gmx.net"
   finaleplugin.CategoryTags = "Page, Text"
   return "Search and Replace Text Blocks in All Open Documents", "", "Searches and replaces strings in text blocks in all open documents"
end


-- ================================================
-- This script searches for text in all page text blocks in all
-- open documents. If the "search" string is found, it will be
-- replaced with the "replace" string". Then the document is saved.
-- The script doesn't care about Enigma commands
-- (see http://jwmusic.nu/jwplugins/wiki/doku.php?id=jwlua:enigmastrings )
-- which do text formatting in Finale. So basically you can search
-- and replace them too, but better learn their syntax first.
-- The script doesn't contain a user interface as it is aimed at batch processing.
-- ================================================

local ui = finenv.UI()
local search, replace = finale.FCString(), finale.FCString()

-- the string to be searched:
-- CHANGE THAT as you like
search.LuaString = "4, rue Saint-Antoine 28410 Bû"

-- the string with which the search string will be replaced:
-- CHANGE THAT as you like
replace.LuaString = "55 Rue du Faubourg Saint-Honoré, 75008 Paris"

for document in loadall(finale.FCDocuments()) do
    local undoblock = finale.FCString()
    document:SwitchTo( undoblock, false )

    -- search all PageTexts for the "search" string and replace it with the "replace" string
    for PageText in loadall( finale.FCPageTexts() ) do
        local PageTextAsString = PageText:CreateTextString()
        local pos = PageTextAsString:CalcStringPos( search )
        if pos>(-1) then
            PageTextAsString:DeleteCharactersAt(pos, search.Length)  -- delete the search string
            PageTextAsString:InsertString( replace, pos)   -- insert the replace string
            PageText:SaveTextString( PageTextAsString )   -- save the PageText
        end
    end

    ui:RedrawDocument()  -- update the view
    document:SwitchBack(true)  -- switch back from document
    document:Save()  -- save the document
end